==> qtjambi-help-debuginfo-linux-x64-6.5.3.jar: sources/QtJambiHelp/QHelpLink_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtHelp/qhelplink.h>
#include <QtCore/QVariant>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QHelpLink(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QHelpLink")
    QHelpLink *_ptr = reinterpret_cast<QHelpLink *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new 
void __qt_construct_QHelpLink_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct ")
    Q_UNUSED(__java_arguments)
    QHelpLink *__qt_this = new(__qtjambi_ptr) QHelpLink();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// destruct QHelpLink
void __qt_destruct_QHelpLink(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QHelpLink")
    reinterpret_cast<QHelpLink*>(ptr)->~QHelpLink();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QHelpLink::
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_help_QHelpLink_initialize_1native__Lio_qt_help_QHelpLink_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QHelpLink::")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QHelpLink_0, sizeof(QHelpLink), typeid(QHelpLink), false, &deleter_QHelpLink, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting Field accessors (writeFieldAccessors)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_help_QHelpLink_setTitle_1native_1cref_1QString__JLjava_lang_String_2)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jstring title0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QHelpLink *__qt_this = QtJambiAPI::objectFromNativeId<QHelpLink>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QString  __qt_title0 = qtjambi_cast<QString >(__jni_env, title0);
        __qt_this->title = __qt_title0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_help_QHelpLink_title_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QHelpLink *__qt_this = QtJambiAPI::objectFromNativeId<QHelpLink>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        const QString&  __qt_value = __qt_this->title;
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_help_QHelpLink_setUrl_1native_1cref_1QUrl__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID url0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QHelpLink *__qt_this = QtJambiAPI::objectFromNativeId<QHelpLink>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        const QUrl& __qt_url0 = QtJambiAPI::valueReferenceFromNativeId<QUrl>(url0);
        __qt_this->url = __qt_url0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_help_QHelpLink_url_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QHelpLink *__qt_this = QtJambiAPI::objectFromNativeId<QHelpLink>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        const QUrl&  __qt_value = __qt_this->url;
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

// emitting (writeJavaLangObjectOverrideFunctions)
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_help_QHelpLink_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QHelpLink *__qt_this = QtJambiAPI::objectFromNativeId<QHelpLink>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QHelpLink(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QHelpLink>("QHelpLink", "io/qt/help/QHelpLink");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QHelpLink, {
        ConstructorInfo(&__qt_construct_QHelpLink_0, nullptr)
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QHelpLink);
    registerMetaType<QHelpLink>("QHelpLink");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-help-debuginfo-linux-x64-6.5.5.jar: sources/QtJambiHelp/QHelpLink_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtHelp/qhelplink.h>
#include <QtCore/QVariant>
#include <QtCore/qurl.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QHelpLink(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QHelpLink")
    QHelpLink *_ptr = reinterpret_cast<QHelpLink *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QHelpLink()
void __qt_construct_QHelpLink(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QHelpLink()")
    Q_UNUSED(__java_arguments)
    QHelpLink *__qt_this = new(__qtjambi_ptr) QHelpLink();
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// QHelpLink::QHelpLink()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_help_QHelpLink_initialize_1native__Lio_qt_help_QHelpLink_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QHelpLink::QHelpLink()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QHelpLink, sizeof(QHelpLink), typeid(QHelpLink), false, &deleter_QHelpLink, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new QHelpLink(QHelpLink)
void __qt_construct_QHelpLink_cref_QHelpLink(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QHelpLink(QHelpLink)")
    jobject other0 = __java_arguments[0].l;
    const QHelpLink& __qt_other0 = qtjambi_cast<const QHelpLink& >(__jni_env, other0);
    QHelpLink *__qt_this = new(__qtjambi_ptr) QHelpLink(__qt_other0);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QHelpLink::QHelpLink(QHelpLink)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_help_QHelpLink_initialize_1native__Lio_qt_help_QHelpLink_2Lio_qt_help_QHelpLink_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QHelpLink::QHelpLink(QHelpLink)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QHelpLink_cref_QHelpLink, sizeof(QHelpLink), typeid(QHelpLink), false, &deleter_QHelpLink, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new QHelpLink{QUrl,QString}
void __qt_construct_QHelpLink_QUrl_QString(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QHelpLink{QUrl,QString}")
    jobject url0 = __java_arguments[0].l;
    QUrl __qt_url0 = qtjambi_cast<QUrl >(__jni_env, url0);
    jstring title1 = static_cast<jstring>(__java_arguments[1].l);
    QString  __qt_title1 = qtjambi_cast<QString>(__jni_env, title1);
    QHelpLink *__qt_this = new(__qtjambi_ptr) QHelpLink{__qt_url0, __qt_title1};
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QHelpLink::QHelpLink{QUrl,QString}
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_help_QHelpLink_initialize_1native__Lio_qt_help_QHelpLink_2Lio_qt_core_QUrl_2Ljava_lang_String_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject url0,
 jstring title1)
{
    QTJAMBI_NATIVE_METHOD_CALL("QHelpLink::QHelpLink{QUrl,QString}")
    QTJAMBI_TRY {
        jvalue arguments[2];
        arguments[0].l = url0;
        arguments[1].l = title1;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QHelpLink_QUrl_QString, sizeof(QHelpLink), typeid(QHelpLink), false, &deleter_QHelpLink, arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QHelpLink
void __qt_destruct_QHelpLink(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QHelpLink")
    reinterpret_cast<QHelpLink*>(ptr)->~QHelpLink();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// emitting Field accessors (writeFieldAccessors)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_help_QHelpLink_setTitle_1native_1cref_1QString__JLjava_lang_String_2)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jstring title0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QHelpLink *__qt_this = QtJambiAPI::objectFromNativeId<QHelpLink>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QString  __qt_title0 = qtjambi_cast<QString>(__jni_env, title0);
        __qt_this->title = __qt_title0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_help_QHelpLink_title_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QHelpLink *__qt_this = QtJambiAPI::objectFromNativeId<QHelpLink>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        const QString&  __qt_value = __qt_this->title;
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_help_QHelpLink_setUrl_1native_1cref_1QUrl__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID url0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QHelpLink *__qt_this = QtJambiAPI::objectFromNativeId<QHelpLink>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        const QUrl& __qt_url0 = QtJambiAPI::valueReferenceFromNativeId<QUrl>(url0);
        __qt_this->url = __qt_url0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_help_QHelpLink_url_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QHelpLink *__qt_this = QtJambiAPI::objectFromNativeId<QHelpLink>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        const QUrl&  __qt_value = __qt_this->url;
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

// emitting (writeJavaLangObjectOverrideFunctions)
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_help_QHelpLink_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QHelpLink *__qt_this = QtJambiAPI::objectFromNativeId<QHelpLink>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QHelpLink(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QHelpLink>("QHelpLink", "io/qt/help/QHelpLink");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QHelpLink, {
        ConstructorInfo(&__qt_construct_QHelpLink, nullptr)
       ,ConstructorInfo(&__qt_construct_QHelpLink_cref_QHelpLink, "Lio/qt/help/QHelpLink;")
       ,ConstructorInfo(&__qt_construct_QHelpLink_QUrl_QString, "Lio/qt/core/QUrl;Ljava/lang/String;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QHelpLink);
    registerMetaType<QHelpLink>("QHelpLink");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
